==> kubernetes-model-policy-5.1.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/policy/SupplementalGroupsStrategyOptionsBuilder.java <==
package io.fabric8.kubernetes.api.model.policy;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SupplementalGroupsStrategyOptionsBuilder extends SupplementalGroupsStrategyOptionsFluentImpl<SupplementalGroupsStrategyOptionsBuilder> implements VisitableBuilder<SupplementalGroupsStrategyOptions,SupplementalGroupsStrategyOptionsBuilder> {

    SupplementalGroupsStrategyOptionsFluent<?> fluent;
    Boolean validationEnabled;

    public SupplementalGroupsStrategyOptionsBuilder() {
        this(true);
    }

    public SupplementalGroupsStrategyOptionsBuilder(Boolean validationEnabled) {
        this(new SupplementalGroupsStrategyOptions(), validationEnabled);
    }

    public SupplementalGroupsStrategyOptionsBuilder(SupplementalGroupsStrategyOptionsFluent<?> fluent) {
        this(fluent, true);
    }

    public SupplementalGroupsStrategyOptionsBuilder(SupplementalGroupsStrategyOptionsFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new SupplementalGroupsStrategyOptions(), validationEnabled);
    }

    public SupplementalGroupsStrategyOptionsBuilder(SupplementalGroupsStrategyOptionsFluent<?> fluent,SupplementalGroupsStrategyOptions instance) {
        this(fluent, instance, true);
    }

    public SupplementalGroupsStrategyOptionsBuilder(SupplementalGroupsStrategyOptionsFluent<?> fluent,SupplementalGroupsStrategyOptions instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withRanges(instance.getRanges()); 
        fluent.withRule(instance.getRule()); 
        this.validationEnabled = validationEnabled; 
    }

    public SupplementalGroupsStrategyOptionsBuilder(SupplementalGroupsStrategyOptions instance) {
        this(instance,true);
    }

    public SupplementalGroupsStrategyOptionsBuilder(SupplementalGroupsStrategyOptions instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withRanges(instance.getRanges()); 
        this.withRule(instance.getRule()); 
        this.validationEnabled = validationEnabled; 
    }

    public SupplementalGroupsStrategyOptions build() {
        SupplementalGroupsStrategyOptions buildable = new SupplementalGroupsStrategyOptions(fluent.getRanges(),fluent.getRule());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SupplementalGroupsStrategyOptionsBuilder that = (SupplementalGroupsStrategyOptionsBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-policy-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/policy/SupplementalGroupsStrategyOptionsBuilder.java <==
package io.fabric8.kubernetes.api.model.policy;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SupplementalGroupsStrategyOptionsBuilder extends SupplementalGroupsStrategyOptionsFluentImpl<SupplementalGroupsStrategyOptionsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<SupplementalGroupsStrategyOptions,SupplementalGroupsStrategyOptionsBuilder> {

    SupplementalGroupsStrategyOptionsFluent<?> fluent;
    Boolean validationEnabled;

    public SupplementalGroupsStrategyOptionsBuilder() {
        this(true);
    }

    public SupplementalGroupsStrategyOptionsBuilder(Boolean validationEnabled) {
        this(new SupplementalGroupsStrategyOptions(), validationEnabled);
    }

    public SupplementalGroupsStrategyOptionsBuilder(SupplementalGroupsStrategyOptionsFluent<?> fluent) {
        this(fluent, true);
    }

    public SupplementalGroupsStrategyOptionsBuilder(SupplementalGroupsStrategyOptionsFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new SupplementalGroupsStrategyOptions(), validationEnabled);
    }

    public SupplementalGroupsStrategyOptionsBuilder(SupplementalGroupsStrategyOptionsFluent<?> fluent,SupplementalGroupsStrategyOptions instance) {
        this(fluent, instance, true);
    }

    public SupplementalGroupsStrategyOptionsBuilder(SupplementalGroupsStrategyOptionsFluent<?> fluent,SupplementalGroupsStrategyOptions instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withRanges(instance.getRanges()); 
        fluent.withRule(instance.getRule()); 
        this.validationEnabled = validationEnabled; 
    }

    public SupplementalGroupsStrategyOptionsBuilder(SupplementalGroupsStrategyOptions instance) {
        this(instance,true);
    }

    public SupplementalGroupsStrategyOptionsBuilder(SupplementalGroupsStrategyOptions instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withRanges(instance.getRanges()); 
        this.withRule(instance.getRule()); 
        this.validationEnabled = validationEnabled; 
    }

    public SupplementalGroupsStrategyOptions build() {
        SupplementalGroupsStrategyOptions buildable = new SupplementalGroupsStrategyOptions(fluent.getRanges(),fluent.getRule());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SupplementalGroupsStrategyOptionsBuilder that = (SupplementalGroupsStrategyOptionsBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
